==> igniteui-react-core-18.5.2-beta.0.tgz: package/esm2015/lib/WebBaseComboBoxLikeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseComboBoxLikeDescription } from "./WebBaseComboBoxLikeDescription";
/**
 * @hidden
 */
export let WebBaseComboBoxLikeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseComboBoxLikeDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseComboBoxLikeDescriptionMetadata.a == null) {
                WebBaseComboBoxLikeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseComboBoxLikeDescriptionMetadata.c(WebBaseComboBoxLikeDescriptionMetadata.a);
            }
            if (a.k(WebBaseComboBoxLikeDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebBaseComboBoxLikeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:BaseComboBoxLike");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("EmitEvent", "Unknown");
            a.item("KeepOpenOnSelect", "Boolean");
            a.item("KeepOpenOnOutsideClick", "Boolean");
            a.item("Open", "Boolean");
        }
        static d(a) {
            WebBaseComboBoxLikeDescriptionMetadata.b(a);
            a.ad("WebBaseComboBoxLike", () => new WebBaseComboBoxLikeDescription());
            a.ac("WebBaseComboBoxLike", WebBaseComboBoxLikeDescriptionMetadata.a);
        }
    }
    WebBaseComboBoxLikeDescriptionMetadata.$t = /*@__PURE__*/ markType(WebBaseComboBoxLikeDescriptionMetadata, 'WebBaseComboBoxLikeDescriptionMetadata');
    WebBaseComboBoxLikeDescriptionMetadata.a = null;
    return WebBaseComboBoxLikeDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.0.tgz: package/esm2015/lib/WebBaseComboBoxLikeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebBaseComboBoxLikeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseComboBoxLikeDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseComboBoxLikeDescriptionMetadata.a == null) {
                WebBaseComboBoxLikeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseComboBoxLikeDescriptionMetadata.c(WebBaseComboBoxLikeDescriptionMetadata.a);
            }
            if (a.k(WebBaseComboBoxLikeDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebBaseComboBoxLikeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:BaseComboBoxLike");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("EmitEvent", "Unknown");
            a.item("KeepOpenOnSelect", "Boolean");
            a.item("KeepOpenOnOutsideClick", "Boolean");
            a.item("Open", "Boolean");
        }
        static d(a) {
            WebBaseComboBoxLikeDescriptionMetadata.b(a);
            a.ad("WebBaseComboBoxLike", WebBaseComboBoxLikeDescriptionMetadata.a);
        }
    }
    WebBaseComboBoxLikeDescriptionMetadata.$t = /*@__PURE__*/ markType(WebBaseComboBoxLikeDescriptionMetadata, 'WebBaseComboBoxLikeDescriptionMetadata');
    WebBaseComboBoxLikeDescriptionMetadata.a = null;
    return WebBaseComboBoxLikeDescriptionMetadata;
})();
